@@ -10,16 +10,25 @@ use std::str::FromStr;
 #[cfg(feature = "serde")]
 use serde::{Deserialize, Deserializer, Serialize, Serializer};
 
+/// A rust variant of the Postgres Numeric type. The full spectrum of Postgres'
+/// Numeric value range is supported.
+///
+/// Represented as an Optional BigDecimal. None for 'NaN', Some(bigdecimal) for
+/// all other values.
 #[derive(Debug, Ord, PartialOrd, Eq, PartialEq, Clone)]
 pub struct PgNumeric {
     pub n: Option<BigDecimal>,
 }
 
 impl PgNumeric {
+    /// Construct a new PgNumeric value from an optional BigDecimal
+    /// (None for NaN values).
     pub fn new(n: Option<BigDecimal>) -> Self {
         Self { n }
     }
 
+    /// Returns true if this PgNumeric value represents a NaN value.
+    /// Otherwise returns false.
     pub fn is_nan(&self) -> bool {
         self.n.is_none()
     }
@@ -300,11 +309,25 @@ fn integration_tests() {
             .execute("INSERT INTO foobar VALUES ($1)", &[&pgnumeric])
             .unwrap();
 
-        let got: Option<PgNumeric> = dbconn
+        let got: PgNumeric = dbconn
             .query_one("SELECT n FROM foobar", &[])
             .unwrap()
-            .get(0);
-        assert_eq!(pgnumeric, got.unwrap());
+            .get::<usize, Option<PgNumeric>>(0)
+            .unwrap();
+        assert_eq!(pgnumeric, got);
+
+        let got_as_str: String = dbconn
+            .query_one("SELECT n::text FROM foobar", &[])
+            .unwrap()
+            .get::<usize, Option<String>>(0)
+            .unwrap();
+        let got = match got_as_str.as_str() {
+            "NaN" => PgNumeric { n: None },
+            s => PgNumeric {
+                n: Some(BigDecimal::from_str(s).unwrap()),
+            },
+        };
+        assert_eq!(pgnumeric, got);
     };
 
     let tests = &[
